__author__ = 'v.denisov'
from rais.client_reguest import ClientReguest as cr
from rais.parameter_initialization import ParameterInitialization as pi

class SessionHelper:

    def __init__(self):
        pass

    def logout(self):
        pass

    @classmethod
    def login(self, username, password, profiles_cookie, language):
        """
        Выполняет логин к rais и сохраняет полученные cooke

        :param username:
        :type username:
        :param password:
        :type password:
        :param profiles_cookie:
        :type profiles_cookie:
        :param language:
        :type language:
        :return:
        :rtype:
        """
        response = cr.get(url=pi.get_url_host()+'/get_rsid')
        for cookie in response.cookies:
            if cookie.name in 'rsid':
                cookie_domain=cookie.domain
                break
        cookies_jar = response.cookies
        cookies_jar.set('profile', profiles_cookie, domain=cookie_domain)
        pi.set_cookies(cookies_jar)

        params = {
            "login": username,
            "pass" : password,
            "lang" : language
        }
        response_login = cr.post(url=pi.get_url_host() + '/interface/orange/user/login', params=params)
        return response_login






__author__ = 'v.denisov'


class ConfigHost():

    def __init__(self):
        self._url_host = None
        self._cookies = None
        self._headers = None
        self._prefix = None

    @property
    def url_host(self):
        return self._url_host

    @url_host.setter
    def set_url_host(self, value):
        self._url_host = value

    @property
    def cookies(self):
        return self._cookies

    @cookies.setter
    def set_cookies(self, value):
        self._cookies = value

    @property
    def headers(self):
        return self._headers

    @headers.setter
    def set_headers(self, value):
        self._headers = value

    @property
    def prefix(self):
        return self._prefix

    @prefix.setter
    def set_prefix(self, value):
        self._prefix = value



__author__ = 'v.denisov'
from rais.data.interested_parties import InterestedParties as ip
from rais.parameter_initialization import ParameterInitialization as pi

class CreateInterestedParties:

    def __init__(self):
        pass

    def check_availability(self, name_ip):
        params = {
            "with": "aliases,requisites,type,orgs",
            "total": 769611,
            "limit": 25,
            "page": 1,
            "search_blike": name_ip,
            "no_count": 1
        }
        response = self.app.regusts.get(url=self.app.base_url + 'api/red/contragent/list', params=params)
        r_json = response.json()
        print('r_json=', r_json)
        if len(r_json["data"]["list"])>0:
            print('Заинтересованная сторона '+name_ip+' уже существует')
            return True
        else:
            return False

    @classmethod
    def person(self, type_person):
        ip_person = ip[type_person]
        # if ip_person[name_first]:
        #     pass
        print(ip_person)
        return ip_person


# -*- coding: utf-8 -*-
__author__ = 'v.denisov'

import allure
import time
from rais.config_host import ConfigHost as config
from rais.reguest import RegustsHelper as rh

class ClientReguest():

    def __init__(self):
        pass

    @classmethod
    def setting_parameters(cls, url, paths, cookies, headers):
        if isinstance(config.cookies, property):
            config.cookies = None
        if isinstance(config.headers, property):
            config.headers = None
        if url is None:
            url = config.url_host + paths
        else:
            url = url + paths
        if cookies is None:
            cookies = config.cookies
        if headers is None:
            headers = config.headers
        return url, cookies, headers

    @classmethod
    @allure.step('get')
    def get(self, url=None, paths='', cookies=None, params=None, headers=None,
            number_of_cycles=5, no_check_response=False):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        for nc in range(number_of_cycles):
            response = rh.get(url=url, cookies=cookies, params=params, headers=headers)
            if response.ok:
                if no_check_response or response.json()['success']:
                    break
            time.sleep(2)
        else:
            print('Запрос не прошел ', url)
            assert False
        return response

    @classmethod
    @allure.step('post')
    def post(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None,
            number_of_cycles=5, no_check_response=False):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        for nc in range(number_of_cycles):
            response = rh.post(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
            if response.ok:
                if no_check_response or response.json()['success']:
                    break
            time.sleep(2)
        else:
            print('Запрос не прошел ', url)
            assert False
        return response

    @classmethod
    @allure.step('delete')
    def delete(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.delete(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('options')
    def options(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.options(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('head')
    def head(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.head(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('put')
    def put(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.put(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('patch')
    def patch(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.patch(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response
